# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_iot.proto\x12\x13oak9.tython.aws.iot\x1a\x13shared/shared.proto\"[\n AuthorizerTokenSigningPublicKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x01\n\x0e\x41uthorizerTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12;\n\x04tags\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iot.AuthorizerTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xce\x02\n\nAuthorizer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x61uthorizer_function_arn\x18\x02 \x01(\t\x12\x17\n\x0f\x61uthorizer_name\x18\x03 \x01(\t\x12\x18\n\x10signing_disabled\x18\x04 \x01(\x08\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x16\n\x0etoken_key_name\x18\x06 \x01(\t\x12X\n\x19token_signing_public_keys\x18\x07 \x01(\x0b\x32\x35.oak9.tython.aws.iot.AuthorizerTokenSigningPublicKeys\x12\x31\n\x04tags\x18\x08 \x01(\x0b\x32#.oak9.tython.aws.iot.AuthorizerTags\"\xef\x03\n\x03IoT\x12\x33\n\nauthorizer\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.iot.Authorizer\x12\x35\n\x0b\x63\x65rtificate\x18\x02 \x03(\x0b\x32 .oak9.tython.aws.iot.Certificate\x12+\n\x06policy\x18\x03 \x03(\x0b\x32\x1b.oak9.tython.aws.iot.Policy\x12S\n\x1bpolicy_principal_attachment\x18\x04 \x03(\x0b\x32..oak9.tython.aws.iot.PolicyPrincipalAttachment\x12H\n\x15provisioning_template\x18\x05 \x03(\x0b\x32).oak9.tython.aws.iot.ProvisioningTemplate\x12)\n\x05thing\x18\x06 \x03(\x0b\x32\x1a.oak9.tython.aws.iot.Thing\x12Q\n\x1athing_principal_attachment\x18\x07 \x03(\x0b\x32-.oak9.tython.aws.iot.ThingPrincipalAttachment\x12\x32\n\ntopic_rule\x18\x08 \x03(\x0b\x32\x1e.oak9.tython.aws.iot.TopicRule\"\xca\x01\n\x0b\x43\x65rtificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63\x61_certificate_pem\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_pem\x18\x03 \x01(\t\x12#\n\x1b\x63\x65rtificate_signing_request\x18\x04 \x01(\t\x12\x18\n\x10\x63\x65rtificate_mode\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\"\xd7\x01\n\x06Policy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\x0fpolicy_document\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.iot.Policy.PolicyDocumentEntry\x12\x13\n\x0bpolicy_name\x18\x03 \x01(\t\x1a\x35\n\x13PolicyDocumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x19PolicyPrincipalAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x11\n\tprincipal\x18\x03 \x01(\t\"\x8c\x01\n$ProvisioningTemplateProvisioningHook\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntarget_arn\x18\x02 \x01(\t\x12\x17\n\x0fpayload_version\x18\x03 \x01(\t\"\xc7\x01\n\x18ProvisioningTemplateTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x04tags\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.iot.ProvisioningTemplateTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x02\n\x14ProvisioningTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rtemplate_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x1d\n\x15provisioning_role_arn\x18\x05 \x01(\t\x12\x15\n\rtemplate_body\x18\x06 \x01(\t\x12X\n\x15pre_provisioning_hook\x18\x07 \x01(\x0b\x32\x39.oak9.tython.aws.iot.ProvisioningTemplateProvisioningHook\x12;\n\x04tags\x18\x08 \x01(\x0b\x32-.oak9.tython.aws.iot.ProvisioningTemplateTags\"\xd3\x01\n\x15ThingAttributePayload\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\nattributes\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.iot.ThingAttributePayload.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9b\x01\n\x05Thing\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x11\x61ttribute_payload\x18\x02 \x01(\x0b\x32*.oak9.tython.aws.iot.ThingAttributePayload\x12\x12\n\nthing_name\x18\x03 \x01(\t\"z\n\x18ThingPrincipalAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tprincipal\x18\x02 \x01(\t\x12\x12\n\nthing_name\x18\x03 \x01(\t\"\xaa\x01\n\x1eTopicRuleCloudwatchAlarmAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nalarm_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x14\n\x0cstate_reason\x18\x04 \x01(\t\x12\x13\n\x0bstate_value\x18\x05 \x01(\t\"\xe0\x01\n\x1fTopicRuleCloudwatchMetricAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x18\n\x10metric_namespace\x18\x03 \x01(\t\x12\x18\n\x10metric_timestamp\x18\x04 \x01(\t\x12\x13\n\x0bmetric_unit\x18\x05 \x01(\t\x12\x14\n\x0cmetric_value\x18\x06 \x01(\t\x12\x10\n\x08role_arn\x18\x07 \x01(\t\"\xa0\x02\n\x17TopicRuleDynamoDBAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0ehash_key_field\x18\x02 \x01(\t\x12\x15\n\rhash_key_type\x18\x03 \x01(\t\x12\x16\n\x0ehash_key_value\x18\x04 \x01(\t\x12\x15\n\rpayload_field\x18\x05 \x01(\t\x12\x17\n\x0frange_key_field\x18\x06 \x01(\t\x12\x16\n\x0erange_key_type\x18\x07 \x01(\t\x12\x17\n\x0frange_key_value\x18\x08 \x01(\t\x12\x10\n\x08role_arn\x18\t \x01(\t\x12\x12\n\ntable_name\x18\n \x01(\t\"d\n\x15TopicRulePutItemInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\"\xa4\x01\n\x19TopicRuleDynamoDBv2Action\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x08put_item\x18\x02 \x01(\x0b\x32*.oak9.tython.aws.iot.TopicRulePutItemInput\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x96\x01\n\x1cTopicRuleElasticsearchAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\x95\x01\n\x17TopicRuleFirehoseAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x64\x65livery_stream_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x11\n\tseparator\x18\x04 \x01(\t\"\x96\x01\n\x1bTopicRuleSigV4Authorization\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12\x14\n\x0cservice_name\x18\x03 \x01(\t\x12\x16\n\x0esigning_region\x18\x04 \x01(\t\"\x96\x01\n\x1aTopicRuleHttpAuthorization\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\x05sigv4\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.iot.TopicRuleSigV4Authorization\"p\n\x19TopicRuleHttpActionHeader\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xf5\x01\n\x13TopicRuleHttpAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x04\x61uth\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.iot.TopicRuleHttpAuthorization\x12\x18\n\x10\x63onfirmation_url\x18\x03 \x01(\t\x12?\n\x07headers\x18\x04 \x03(\x0b\x32..oak9.tython.aws.iot.TopicRuleHttpActionHeader\x12\x0b\n\x03url\x18\x05 \x01(\t\"~\n\x1bTopicRuleIotAnalyticsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x8d\x01\n\x18TopicRuleIotEventsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ninput_name\x18\x02 \x01(\t\x12\x12\n\nmessage_id\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"\x8c\x01\n\x1fTopicRuleAssetPropertyTimestamp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0foffset_in_nanos\x18\x02 \x01(\t\x12\x17\n\x0ftime_in_seconds\x18\x03 \x01(\t\"\xb2\x01\n\x1dTopicRuleAssetPropertyVariant\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rboolean_value\x18\x02 \x01(\t\x12\x14\n\x0c\x64ouble_value\x18\x03 \x01(\t\x12\x15\n\rinteger_value\x18\x04 \x01(\t\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\"\xf3\x01\n\x1bTopicRuleAssetPropertyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07quality\x18\x02 \x01(\t\x12G\n\ttimestamp\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.iot.TopicRuleAssetPropertyTimestamp\x12\x41\n\x05value\x18\x04 \x01(\x0b\x32\x32.oak9.tython.aws.iot.TopicRuleAssetPropertyVariant\"\xfa\x01\n#TopicRulePutAssetPropertyValueEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x61sset_id\x18\x02 \x01(\t\x12\x10\n\x08\x65ntry_id\x18\x03 \x01(\t\x12\x16\n\x0eproperty_alias\x18\x04 \x01(\t\x12\x13\n\x0bproperty_id\x18\x05 \x01(\t\x12I\n\x0fproperty_values\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.iot.TopicRuleAssetPropertyValue\"\xcb\x01\n\x1aTopicRuleIotSiteWiseAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n put_asset_property_value_entries\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.iot.TopicRulePutAssetPropertyValueEntry\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x8f\x01\n\x16TopicRuleKinesisAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rpartition_key\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"f\n\x15TopicRuleLambdaAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66unction_arn\x18\x02 \x01(\t\"\x81\x01\n\x18TopicRuleRepublishAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03qos\x18\x02 \x01(\x05\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\r\n\x05topic\x18\x04 \x01(\t\"\x80\x01\n\x11TopicRuleS3Action\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x62ucket_name\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"\x8b\x01\n\x12TopicRuleSnsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0emessage_format\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x12\n\ntarget_arn\x18\x04 \x01(\t\"\x86\x01\n\x12TopicRuleSqsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tqueue_url\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x12\n\nuse_base64\x18\x04 \x01(\x08\"\xa4\x01\n\x1cTopicRuleStepFunctionsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x65xecution_name_prefix\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x1a\n\x12state_machine_name\x18\x04 \x01(\t\"\xad\t\n\x0fTopicRuleAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x10\x63loudwatch_alarm\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.iot.TopicRuleCloudwatchAlarmAction\x12O\n\x11\x63loudwatch_metric\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.iot.TopicRuleCloudwatchMetricAction\x12?\n\tdynamo_db\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.iot.TopicRuleDynamoDBAction\x12\x43\n\x0b\x64ynamo_dbv2\x18\x05 \x01(\x0b\x32..oak9.tython.aws.iot.TopicRuleDynamoDBv2Action\x12H\n\relasticsearch\x18\x06 \x01(\x0b\x32\x31.oak9.tython.aws.iot.TopicRuleElasticsearchAction\x12>\n\x08\x66irehose\x18\x07 \x01(\x0b\x32,.oak9.tython.aws.iot.TopicRuleFirehoseAction\x12\x36\n\x04http\x18\x08 \x01(\x0b\x32(.oak9.tython.aws.iot.TopicRuleHttpAction\x12G\n\riot_analytics\x18\t \x01(\x0b\x32\x30.oak9.tython.aws.iot.TopicRuleIotAnalyticsAction\x12\x41\n\niot_events\x18\n \x01(\x0b\x32-.oak9.tython.aws.iot.TopicRuleIotEventsAction\x12\x46\n\riot_site_wise\x18\x0b \x01(\x0b\x32/.oak9.tython.aws.iot.TopicRuleIotSiteWiseAction\x12<\n\x07kinesis\x18\x0c \x01(\x0b\x32+.oak9.tython.aws.iot.TopicRuleKinesisAction\x12:\n\x06lambda\x18\r \x01(\x0b\x32*.oak9.tython.aws.iot.TopicRuleLambdaAction\x12@\n\trepublish\x18\x0e \x01(\x0b\x32-.oak9.tython.aws.iot.TopicRuleRepublishAction\x12\x32\n\x02s3\x18\x0f \x01(\x0b\x32&.oak9.tython.aws.iot.TopicRuleS3Action\x12\x34\n\x03sns\x18\x10 \x01(\x0b\x32\'.oak9.tython.aws.iot.TopicRuleSnsAction\x12\x34\n\x03sqs\x18\x11 \x01(\x0b\x32\'.oak9.tython.aws.iot.TopicRuleSqsAction\x12I\n\x0estep_functions\x18\x12 \x01(\x0b\x32\x31.oak9.tython.aws.iot.TopicRuleStepFunctionsAction\"\x9d\x02\n\x19TopicRuleTopicRulePayload\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x35\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32$.oak9.tython.aws.iot.TopicRuleAction\x12\x1b\n\x13\x61ws_iot_sql_version\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12:\n\x0c\x65rror_action\x18\x05 \x01(\x0b\x32$.oak9.tython.aws.iot.TopicRuleAction\x12\x15\n\rrule_disabled\x18\x06 \x01(\x08\x12\x0b\n\x03sql\x18\x07 \x01(\t\"\xa3\x01\n\tTopicRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\trule_name\x18\x02 \x01(\t\x12J\n\x12topic_rule_payload\x18\x03 \x01(\x0b\x32..oak9.tython.aws.iot.TopicRuleTopicRulePayloadb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AUTHORIZERTAGS_TAGSENTRY._options = None
  _AUTHORIZERTAGS_TAGSENTRY._serialized_options = b'8\001'
  _POLICY_POLICYDOCUMENTENTRY._options = None
  _POLICY_POLICYDOCUMENTENTRY._serialized_options = b'8\001'
  _PROVISIONINGTEMPLATETAGS_TAGSENTRY._options = None
  _PROVISIONINGTEMPLATETAGS_TAGSENTRY._serialized_options = b'8\001'
  _THINGATTRIBUTEPAYLOAD_ATTRIBUTESENTRY._options = None
  _THINGATTRIBUTEPAYLOAD_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _AUTHORIZERTOKENSIGNINGPUBLICKEYS._serialized_start=63
  _AUTHORIZERTOKENSIGNINGPUBLICKEYS._serialized_end=154
  _AUTHORIZERTAGS._serialized_start=157
  _AUTHORIZERTAGS._serialized_end=336
  _AUTHORIZERTAGS_TAGSENTRY._serialized_start=293
  _AUTHORIZERTAGS_TAGSENTRY._serialized_end=336
  _AUTHORIZER._serialized_start=339
  _AUTHORIZER._serialized_end=673
  _IOT._serialized_start=676
  _IOT._serialized_end=1171
  _CERTIFICATE._serialized_start=1174
  _CERTIFICATE._serialized_end=1376
  _POLICY._serialized_start=1379
  _POLICY._serialized_end=1594
  _POLICY_POLICYDOCUMENTENTRY._serialized_start=1541
  _POLICY_POLICYDOCUMENTENTRY._serialized_end=1594
  _POLICYPRINCIPALATTACHMENT._serialized_start=1596
  _POLICYPRINCIPALATTACHMENT._serialized_end=1720
  _PROVISIONINGTEMPLATEPROVISIONINGHOOK._serialized_start=1723
  _PROVISIONINGTEMPLATEPROVISIONINGHOOK._serialized_end=1863
  _PROVISIONINGTEMPLATETAGS._serialized_start=1866
  _PROVISIONINGTEMPLATETAGS._serialized_end=2065
  _PROVISIONINGTEMPLATETAGS_TAGSENTRY._serialized_start=293
  _PROVISIONINGTEMPLATETAGS_TAGSENTRY._serialized_end=336
  _PROVISIONINGTEMPLATE._serialized_start=2068
  _PROVISIONINGTEMPLATE._serialized_end=2413
  _THINGATTRIBUTEPAYLOAD._serialized_start=2416
  _THINGATTRIBUTEPAYLOAD._serialized_end=2627
  _THINGATTRIBUTEPAYLOAD_ATTRIBUTESENTRY._serialized_start=2578
  _THINGATTRIBUTEPAYLOAD_ATTRIBUTESENTRY._serialized_end=2627
  _THING._serialized_start=2630
  _THING._serialized_end=2785
  _THINGPRINCIPALATTACHMENT._serialized_start=2787
  _THINGPRINCIPALATTACHMENT._serialized_end=2909
  _TOPICRULECLOUDWATCHALARMACTION._serialized_start=2912
  _TOPICRULECLOUDWATCHALARMACTION._serialized_end=3082
  _TOPICRULECLOUDWATCHMETRICACTION._serialized_start=3085
  _TOPICRULECLOUDWATCHMETRICACTION._serialized_end=3309
  _TOPICRULEDYNAMODBACTION._serialized_start=3312
  _TOPICRULEDYNAMODBACTION._serialized_end=3600
  _TOPICRULEPUTITEMINPUT._serialized_start=3602
  _TOPICRULEPUTITEMINPUT._serialized_end=3702
  _TOPICRULEDYNAMODBV2ACTION._serialized_start=3705
  _TOPICRULEDYNAMODBV2ACTION._serialized_end=3869
  _TOPICRULEELASTICSEARCHACTION._serialized_start=3872
  _TOPICRULEELASTICSEARCHACTION._serialized_end=4022
  _TOPICRULEFIREHOSEACTION._serialized_start=4025
  _TOPICRULEFIREHOSEACTION._serialized_end=4174
  _TOPICRULESIGV4AUTHORIZATION._serialized_start=4177
  _TOPICRULESIGV4AUTHORIZATION._serialized_end=4327
  _TOPICRULEHTTPAUTHORIZATION._serialized_start=4330
  _TOPICRULEHTTPAUTHORIZATION._serialized_end=4480
  _TOPICRULEHTTPACTIONHEADER._serialized_start=4482
  _TOPICRULEHTTPACTIONHEADER._serialized_end=4594
  _TOPICRULEHTTPACTION._serialized_start=4597
  _TOPICRULEHTTPACTION._serialized_end=4842
  _TOPICRULEIOTANALYTICSACTION._serialized_start=4844
  _TOPICRULEIOTANALYTICSACTION._serialized_end=4970
  _TOPICRULEIOTEVENTSACTION._serialized_start=4973
  _TOPICRULEIOTEVENTSACTION._serialized_end=5114
  _TOPICRULEASSETPROPERTYTIMESTAMP._serialized_start=5117
  _TOPICRULEASSETPROPERTYTIMESTAMP._serialized_end=5257
  _TOPICRULEASSETPROPERTYVARIANT._serialized_start=5260
  _TOPICRULEASSETPROPERTYVARIANT._serialized_end=5438
  _TOPICRULEASSETPROPERTYVALUE._serialized_start=5441
  _TOPICRULEASSETPROPERTYVALUE._serialized_end=5684
  _TOPICRULEPUTASSETPROPERTYVALUEENTRY._serialized_start=5687
  _TOPICRULEPUTASSETPROPERTYVALUEENTRY._serialized_end=5937
  _TOPICRULEIOTSITEWISEACTION._serialized_start=5940
  _TOPICRULEIOTSITEWISEACTION._serialized_end=6143
  _TOPICRULEKINESISACTION._serialized_start=6146
  _TOPICRULEKINESISACTION._serialized_end=6289
  _TOPICRULELAMBDAACTION._serialized_start=6291
  _TOPICRULELAMBDAACTION._serialized_end=6393
  _TOPICRULEREPUBLISHACTION._serialized_start=6396
  _TOPICRULEREPUBLISHACTION._serialized_end=6525
  _TOPICRULES3ACTION._serialized_start=6528
  _TOPICRULES3ACTION._serialized_end=6656
  _TOPICRULESNSACTION._serialized_start=6659
  _TOPICRULESNSACTION._serialized_end=6798
  _TOPICRULESQSACTION._serialized_start=6801
  _TOPICRULESQSACTION._serialized_end=6935
  _TOPICRULESTEPFUNCTIONSACTION._serialized_start=6938
  _TOPICRULESTEPFUNCTIONSACTION._serialized_end=7102
  _TOPICRULEACTION._serialized_start=7105
  _TOPICRULEACTION._serialized_end=8302
  _TOPICRULETOPICRULEPAYLOAD._serialized_start=8305
  _TOPICRULETOPICRULEPAYLOAD._serialized_end=8590
  _TOPICRULE._serialized_start=8593
  _TOPICRULE._serialized_end=8756
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FilestoreInstanceXFileSharesXNfsExportOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_MODE_FIELD_NUMBER: builtins.int
    ANON_GID_FIELD_NUMBER: builtins.int
    ANON_UID_FIELD_NUMBER: builtins.int
    IP_RANGES_FIELD_NUMBER: builtins.int
    SQUASH_MODE_FIELD_NUMBER: builtins.int
    access_mode: builtins.str
    anon_gid: builtins.float
    anon_uid: builtins.float
    @property
    def ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    squash_mode: builtins.str
    def __init__(
        self,
        *,
        access_mode: builtins.str = ...,
        anon_gid: builtins.float = ...,
        anon_uid: builtins.float = ...,
        ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        squash_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_mode", b"access_mode", "anon_gid", b"anon_gid", "anon_uid", b"anon_uid", "ip_ranges", b"ip_ranges", "squash_mode", b"squash_mode"]) -> None: ...

global___FilestoreInstanceXFileSharesXNfsExportOptions = FilestoreInstanceXFileSharesXNfsExportOptions

@typing_extensions.final
class FilestoreInstanceXFileShares(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_GB_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NFS_EXPORT_OPTIONS_FIELD_NUMBER: builtins.int
    capacity_gb: builtins.float
    name: builtins.str
    @property
    def nfs_export_options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FilestoreInstanceXFileSharesXNfsExportOptions]: ...
    def __init__(
        self,
        *,
        capacity_gb: builtins.float = ...,
        name: builtins.str = ...,
        nfs_export_options: collections.abc.Iterable[global___FilestoreInstanceXFileSharesXNfsExportOptions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity_gb", b"capacity_gb", "name", b"name", "nfs_export_options", b"nfs_export_options"]) -> None: ...

global___FilestoreInstanceXFileShares = FilestoreInstanceXFileShares

@typing_extensions.final
class FilestoreInstanceXNetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECT_MODE_FIELD_NUMBER: builtins.int
    IP_ADDRESSES_FIELD_NUMBER: builtins.int
    MODES_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    RESERVED_IP_RANGE_FIELD_NUMBER: builtins.int
    connect_mode: builtins.str
    @property
    def ip_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def modes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    network: builtins.str
    reserved_ip_range: builtins.str
    def __init__(
        self,
        *,
        connect_mode: builtins.str = ...,
        ip_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        modes: collections.abc.Iterable[builtins.str] | None = ...,
        network: builtins.str = ...,
        reserved_ip_range: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connect_mode", b"connect_mode", "ip_addresses", b"ip_addresses", "modes", b"modes", "network", b"network", "reserved_ip_range", b"reserved_ip_range"]) -> None: ...

global___FilestoreInstanceXNetworks = FilestoreInstanceXNetworks

@typing_extensions.final
class FilestoreInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___FilestoreInstanceXTimeouts = FilestoreInstanceXTimeouts

@typing_extensions.final
class FilestoreInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    FILE_SHARES_FIELD_NUMBER: builtins.int
    NETWORKS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    etag: builtins.str
    id: builtins.str
    kms_key_name: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    tier: builtins.str
    zone: builtins.str
    @property
    def file_shares(self) -> global___FilestoreInstanceXFileShares: ...
    @property
    def networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FilestoreInstanceXNetworks]: ...
    @property
    def timeouts(self) -> global___FilestoreInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tier: builtins.str = ...,
        zone: builtins.str = ...,
        file_shares: global___FilestoreInstanceXFileShares | None = ...,
        networks: collections.abc.Iterable[global___FilestoreInstanceXNetworks] | None = ...,
        timeouts: global___FilestoreInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file_shares", b"file_shares", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "etag", b"etag", "file_shares", b"file_shares", "id", b"id", "kms_key_name", b"kms_key_name", "labels", b"labels", "location", b"location", "name", b"name", "networks", b"networks", "project", b"project", "resource_info", b"resource_info", "tier", b"tier", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___FilestoreInstance = FilestoreInstance



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_firewallpolicies.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4azure/azure_microsoft_network_firewallpolicies.proto\x12\x34oak9.tython.azure.microsoft_network_firewallpolicies\x1a\x13shared/shared.proto\"\x87\x01\n\"Microsoft_Network_firewallPolicies\x12\x61\n\x11\x66irewall_policies\x18\x01 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicies\"\xed\x01\n$FirewallPoliciesRuleCollectionGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12l\n\x10rule_collections\x18\x04 \x03(\x0b\x32R.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyRuleCollection\"\\\n\x1c\x46irewallPolicyRuleCollection\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12\x1c\n\x14rule_collection_type\x18\x03 \x01(\t\"\xa8\x08\n\x10\x46irewallPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12^\n\x04tags\x18\x04 \x03(\x0b\x32P.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicies.TagsEntry\x12\x13\n\x0b\x62\x61se_policy\x18\x05 \x01(\t\x12\x19\n\x11threat_intel_mode\x18\x06 \x01(\t\x12x\n\x16threat_intel_whitelist\x18\x07 \x01(\x0b\x32X.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyThreatIntelWhitelist\x12W\n\x0c\x64ns_settings\x18\x08 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network_firewallpolicies.DnsSettings\x12s\n\x13intrusion_detection\x18\t \x01(\x0b\x32V.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyIntrusionDetection\x12q\n\x12transport_security\x18\n \x01(\x0b\x32U.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyTransportSecurity\x12T\n\x03sku\x18\x0b \x01(\x0b\x32G.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicySku\x12^\n\x08identity\x18\x0c \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_firewallpolicies.ManagedServiceIdentity\x12\x8c\x01\n(firewall_policies_rule_collection_groups\x18\r \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPoliciesRuleCollectionGroups\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf2\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x8a\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32h.oak9.tython.azure.microsoft_network_firewallpolicies.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"!\n\x11\x46irewallPolicySku\x12\x0c\n\x04tier\x18\x01 \x01(\t\"\x9a\x01\n\x1f\x46irewallPolicyTransportSecurity\x12w\n\x15\x63\x65rtificate_authority\x18\x01 \x01(\x0b\x32X.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyCertificateAuthority\"O\n\"FirewallPolicyCertificateAuthority\x12\x1b\n\x13key_vault_secret_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xac\x01\n FirewallPolicyIntrusionDetection\x12\x0c\n\x04mode\x18\x01 \x01(\t\x12z\n\rconfiguration\x18\x02 \x01(\x0b\x32\x63.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyIntrusionDetectionConfiguration\"\xd0\x02\n-FirewallPolicyIntrusionDetectionConfiguration\x12\x89\x01\n\x13signature_overrides\x18\x01 \x03(\x0b\x32l.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyIntrusionDetectionSignatureSpecification\x12\x92\x01\n\x17\x62ypass_traffic_settings\x18\x02 \x03(\x0b\x32q.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyIntrusionDetectionBypassTrafficSpecifications\"\xff\x01\n;FirewallPolicyIntrusionDetectionBypassTrafficSpecifications\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x18\n\x10source_addresses\x18\x04 \x03(\t\x12\x1d\n\x15\x64\x65stination_addresses\x18\x05 \x03(\t\x12\x19\n\x11\x64\x65stination_ports\x18\x06 \x03(\t\x12\x18\n\x10source_ip_groups\x18\x07 \x03(\t\x12\x1d\n\x15\x64\x65stination_ip_groups\x18\x08 \x03(\t\"R\n6FirewallPolicyIntrusionDetectionSignatureSpecification\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\t\"]\n\x0b\x44nsSettings\x12\x0f\n\x07servers\x18\x01 \x03(\t\x12\x14\n\x0c\x65nable_proxy\x18\x02 \x01(\x08\x12\'\n\x1frequire_proxy_for_network_rules\x18\x03 \x01(\x08\"I\n\"FirewallPolicyThreatIntelWhitelist\x12\x14\n\x0cip_addresses\x18\x01 \x03(\t\x12\r\n\x05\x66qdns\x18\x02 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_firewallpolicies_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FIREWALLPOLICIES_TAGSENTRY._options = None
  _FIREWALLPOLICIES_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_FIREWALLPOLICIES._serialized_start=132
  _MICROSOFT_NETWORK_FIREWALLPOLICIES._serialized_end=267
  _FIREWALLPOLICIESRULECOLLECTIONGROUPS._serialized_start=270
  _FIREWALLPOLICIESRULECOLLECTIONGROUPS._serialized_end=507
  _FIREWALLPOLICYRULECOLLECTION._serialized_start=509
  _FIREWALLPOLICYRULECOLLECTION._serialized_end=601
  _FIREWALLPOLICIES._serialized_start=604
  _FIREWALLPOLICIES._serialized_end=1668
  _FIREWALLPOLICIES_TAGSENTRY._serialized_start=1625
  _FIREWALLPOLICIES_TAGSENTRY._serialized_end=1668
  _MANAGEDSERVICEIDENTITY._serialized_start=1671
  _MANAGEDSERVICEIDENTITY._serialized_end=1913
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=1852
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=1913
  _FIREWALLPOLICYSKU._serialized_start=1915
  _FIREWALLPOLICYSKU._serialized_end=1948
  _FIREWALLPOLICYTRANSPORTSECURITY._serialized_start=1951
  _FIREWALLPOLICYTRANSPORTSECURITY._serialized_end=2105
  _FIREWALLPOLICYCERTIFICATEAUTHORITY._serialized_start=2107
  _FIREWALLPOLICYCERTIFICATEAUTHORITY._serialized_end=2186
  _FIREWALLPOLICYINTRUSIONDETECTION._serialized_start=2189
  _FIREWALLPOLICYINTRUSIONDETECTION._serialized_end=2361
  _FIREWALLPOLICYINTRUSIONDETECTIONCONFIGURATION._serialized_start=2364
  _FIREWALLPOLICYINTRUSIONDETECTIONCONFIGURATION._serialized_end=2700
  _FIREWALLPOLICYINTRUSIONDETECTIONBYPASSTRAFFICSPECIFICATIONS._serialized_start=2703
  _FIREWALLPOLICYINTRUSIONDETECTIONBYPASSTRAFFICSPECIFICATIONS._serialized_end=2958
  _FIREWALLPOLICYINTRUSIONDETECTIONSIGNATURESPECIFICATION._serialized_start=2960
  _FIREWALLPOLICYINTRUSIONDETECTIONSIGNATURESPECIFICATION._serialized_end=3042
  _DNSSETTINGS._serialized_start=3044
  _DNSSETTINGS._serialized_end=3137
  _FIREWALLPOLICYTHREATINTELWHITELIST._serialized_start=3139
  _FIREWALLPOLICYTHREATINTELWHITELIST._serialized_end=3212
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from typing import List
from core.bp_metadata_utils.policy import Policy, Validation


@dataclass
class BlueprintMetaData:
    """
    Class to represent blueprint metadata
    """
    # name: str
    # desc: str
    # author: str
    validations: List[Validation]
    
    def __json__(self):
        validations_json_list = []
        if self.validations:
          for validation in self.validations:
            if validation:
              validations_json_list.append(validation.__json__())

        return {
            # 'name': self.name,
            # 'desc': self.desc,
            # 'author': self.author,
            'validations': validations_json_list,
        }



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RepositoryAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    CONNECTION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    type: builtins.str
    owner: builtins.str
    connection_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        type: builtins.str = ...,
        owner: builtins.str = ...,
        connection_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_arn", b"connection_arn", "name", b"name", "owner", b"owner", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___RepositoryAssociation = RepositoryAssociation

@typing_extensions.final
class CodeGuruReviewer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_ASSOCIATION_FIELD_NUMBER: builtins.int
    @property
    def repository_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RepositoryAssociation]: ...
    def __init__(
        self,
        *,
        repository_association: collections.abc.Iterable[global___RepositoryAssociation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository_association", b"repository_association"]) -> None: ...

global___CodeGuruReviewer = CodeGuruReviewer



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MutatingWebhook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMISSION_REVIEW_VERSIONS_FIELD_NUMBER: builtins.int
    CLIENT_CONFIG_FIELD_NUMBER: builtins.int
    FAILURE_POLICY_FIELD_NUMBER: builtins.int
    MATCH_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_SELECTOR_FIELD_NUMBER: builtins.int
    OBJECT_SELECTOR_FIELD_NUMBER: builtins.int
    REINVOCATION_POLICY_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    SIDE_EFFECTS_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def admission_review_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def client_config(self) -> global___WebhookClientConfig: ...
    failure_policy: builtins.str
    match_policy: builtins.str
    name: builtins.str
    @property
    def namespace_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def object_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    reinvocation_policy: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleWithOperations]: ...
    side_effects: builtins.str
    timeout_seconds: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        admission_review_versions: collections.abc.Iterable[builtins.str] | None = ...,
        client_config: global___WebhookClientConfig | None = ...,
        failure_policy: builtins.str = ...,
        match_policy: builtins.str = ...,
        name: builtins.str = ...,
        namespace_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        object_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        reinvocation_policy: builtins.str = ...,
        rules: collections.abc.Iterable[global___RuleWithOperations] | None = ...,
        side_effects: builtins.str = ...,
        timeout_seconds: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_config", b"client_config", "namespace_selector", b"namespace_selector", "object_selector", b"object_selector", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admission_review_versions", b"admission_review_versions", "client_config", b"client_config", "failure_policy", b"failure_policy", "match_policy", b"match_policy", "name", b"name", "namespace_selector", b"namespace_selector", "object_selector", b"object_selector", "reinvocation_policy", b"reinvocation_policy", "resource_info", b"resource_info", "rules", b"rules", "side_effects", b"side_effects", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___MutatingWebhook = MutatingWebhook

@typing_extensions.final
class MutatingWebhookConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    WEBHOOKS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def webhooks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MutatingWebhook]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        webhooks: collections.abc.Iterable[global___MutatingWebhook] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "webhooks", b"webhooks"]) -> None: ...

global___MutatingWebhookConfiguration = MutatingWebhookConfiguration

@typing_extensions.final
class MutatingWebhookConfigurationList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MutatingWebhookConfiguration]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___MutatingWebhookConfiguration] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___MutatingWebhookConfigurationList = MutatingWebhookConfigurationList

@typing_extensions.final
class RuleWithOperations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUPS_FIELD_NUMBER: builtins.int
    API_VERSIONS_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def api_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def api_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    scope: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_groups: collections.abc.Iterable[builtins.str] | None = ...,
        api_versions: collections.abc.Iterable[builtins.str] | None = ...,
        operations: collections.abc.Iterable[builtins.str] | None = ...,
        resources: collections.abc.Iterable[builtins.str] | None = ...,
        scope: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_groups", b"api_groups", "api_versions", b"api_versions", "operations", b"operations", "resource_info", b"resource_info", "resources", b"resources", "scope", b"scope"]) -> None: ...

global___RuleWithOperations = RuleWithOperations

@typing_extensions.final
class ServiceReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    namespace: builtins.str
    path: builtins.str
    port: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        path: builtins.str = ...,
        port: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "namespace", b"namespace", "path", b"path", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___ServiceReference = ServiceReference

@typing_extensions.final
class ValidatingWebhook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMISSION_REVIEW_VERSIONS_FIELD_NUMBER: builtins.int
    CLIENT_CONFIG_FIELD_NUMBER: builtins.int
    FAILURE_POLICY_FIELD_NUMBER: builtins.int
    MATCH_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_SELECTOR_FIELD_NUMBER: builtins.int
    OBJECT_SELECTOR_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    SIDE_EFFECTS_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def admission_review_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def client_config(self) -> global___WebhookClientConfig: ...
    failure_policy: builtins.str
    match_policy: builtins.str
    name: builtins.str
    @property
    def namespace_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def object_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleWithOperations]: ...
    side_effects: builtins.str
    timeout_seconds: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        admission_review_versions: collections.abc.Iterable[builtins.str] | None = ...,
        client_config: global___WebhookClientConfig | None = ...,
        failure_policy: builtins.str = ...,
        match_policy: builtins.str = ...,
        name: builtins.str = ...,
        namespace_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        object_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        rules: collections.abc.Iterable[global___RuleWithOperations] | None = ...,
        side_effects: builtins.str = ...,
        timeout_seconds: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_config", b"client_config", "namespace_selector", b"namespace_selector", "object_selector", b"object_selector", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admission_review_versions", b"admission_review_versions", "client_config", b"client_config", "failure_policy", b"failure_policy", "match_policy", b"match_policy", "name", b"name", "namespace_selector", b"namespace_selector", "object_selector", b"object_selector", "resource_info", b"resource_info", "rules", b"rules", "side_effects", b"side_effects", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___ValidatingWebhook = ValidatingWebhook

@typing_extensions.final
class ValidatingWebhookConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    WEBHOOKS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def webhooks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatingWebhook]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        webhooks: collections.abc.Iterable[global___ValidatingWebhook] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "webhooks", b"webhooks"]) -> None: ...

global___ValidatingWebhookConfiguration = ValidatingWebhookConfiguration

@typing_extensions.final
class ValidatingWebhookConfigurationList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatingWebhookConfiguration]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ValidatingWebhookConfiguration] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ValidatingWebhookConfigurationList = ValidatingWebhookConfigurationList

@typing_extensions.final
class WebhookClientConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_BUNDLE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ca_bundle: builtins.str
    @property
    def service(self) -> global___ServiceReference: ...
    url: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ca_bundle: builtins.str = ...,
        service: global___ServiceReference | None = ...,
        url: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_bundle", b"ca_bundle", "resource_info", b"resource_info", "service", b"service", "url", b"url"]) -> None: ...

global___WebhookClientConfig = WebhookClientConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServiceAccountXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create"]) -> None: ...

global___ServiceAccountXTimeouts = ServiceAccountXTimeouts

@typing_extensions.final
class ServiceAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    description: builtins.str
    disabled: builtins.bool
    display_name: builtins.str
    email: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    unique_id: builtins.str
    @property
    def timeouts(self) -> global___ServiceAccountXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        display_name: builtins.str = ...,
        email: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        unique_id: builtins.str = ...,
        timeouts: global___ServiceAccountXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "description", b"description", "disabled", b"disabled", "display_name", b"display_name", "email", b"email", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "unique_id", b"unique_id"]) -> None: ...

global___ServiceAccount = ServiceAccount

@typing_extensions.final
class ServiceAccountIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ServiceAccountIamBindingXCondition = ServiceAccountIamBindingXCondition

@typing_extensions.final
class ServiceAccountIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    service_account_id: builtins.str
    @property
    def condition(self) -> global___ServiceAccountIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        service_account_id: builtins.str = ...,
        condition: global___ServiceAccountIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role", "service_account_id", b"service_account_id"]) -> None: ...

global___ServiceAccountIamBinding = ServiceAccountIamBinding

@typing_extensions.final
class ServiceAccountIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ServiceAccountIamMemberXCondition = ServiceAccountIamMemberXCondition

@typing_extensions.final
class ServiceAccountIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    service_account_id: builtins.str
    @property
    def condition(self) -> global___ServiceAccountIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        service_account_id: builtins.str = ...,
        condition: global___ServiceAccountIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role", "service_account_id", b"service_account_id"]) -> None: ...

global___ServiceAccountIamMember = ServiceAccountIamMember

@typing_extensions.final
class ServiceAccountIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    service_account_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        service_account_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info", "service_account_id", b"service_account_id"]) -> None: ...

global___ServiceAccountIamPolicy = ServiceAccountIamPolicy

@typing_extensions.final
class ServiceAccountKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class KeepersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    KEEPERS_FIELD_NUMBER: builtins.int
    KEY_ALGORITHM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_TYPE_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_DATA_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_TYPE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    VALID_AFTER_FIELD_NUMBER: builtins.int
    VALID_BEFORE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def keepers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    key_algorithm: builtins.str
    name: builtins.str
    private_key: builtins.str
    private_key_type: builtins.str
    public_key: builtins.str
    public_key_data: builtins.str
    public_key_type: builtins.str
    service_account_id: builtins.str
    valid_after: builtins.str
    valid_before: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        keepers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        key_algorithm: builtins.str = ...,
        name: builtins.str = ...,
        private_key: builtins.str = ...,
        private_key_type: builtins.str = ...,
        public_key: builtins.str = ...,
        public_key_data: builtins.str = ...,
        public_key_type: builtins.str = ...,
        service_account_id: builtins.str = ...,
        valid_after: builtins.str = ...,
        valid_before: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "keepers", b"keepers", "key_algorithm", b"key_algorithm", "name", b"name", "private_key", b"private_key", "private_key_type", b"private_key_type", "public_key", b"public_key", "public_key_data", b"public_key_data", "public_key_type", b"public_key_type", "resource_info", b"resource_info", "service_account_id", b"service_account_id", "valid_after", b"valid_after", "valid_before", b"valid_before"]) -> None: ...

global___ServiceAccountKey = ServiceAccountKey

@typing_extensions.final
class ServiceNetworkingConnectionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ServiceNetworkingConnectionXTimeouts = ServiceNetworkingConnectionXTimeouts

@typing_extensions.final
class ServiceNetworkingConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PEERING_FIELD_NUMBER: builtins.int
    RESERVED_PEERING_RANGES_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    network: builtins.str
    peering: builtins.str
    @property
    def reserved_peering_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service: builtins.str
    @property
    def timeouts(self) -> global___ServiceNetworkingConnectionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        network: builtins.str = ...,
        peering: builtins.str = ...,
        reserved_peering_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        service: builtins.str = ...,
        timeouts: global___ServiceNetworkingConnectionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "network", b"network", "peering", b"peering", "reserved_peering_ranges", b"reserved_peering_ranges", "resource_info", b"resource_info", "service", b"service", "timeouts", b"timeouts"]) -> None: ...

global___ServiceNetworkingConnection = ServiceNetworkingConnection

@typing_extensions.final
class ServiceNetworkingPeeredDnsDomainXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read"]) -> None: ...

global___ServiceNetworkingPeeredDnsDomainXTimeouts = ServiceNetworkingPeeredDnsDomainXTimeouts

@typing_extensions.final
class ServiceNetworkingPeeredDnsDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_SUFFIX_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dns_suffix: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    parent: builtins.str
    project: builtins.str
    service: builtins.str
    @property
    def timeouts(self) -> global___ServiceNetworkingPeeredDnsDomainXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dns_suffix: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        parent: builtins.str = ...,
        project: builtins.str = ...,
        service: builtins.str = ...,
        timeouts: global___ServiceNetworkingPeeredDnsDomainXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_suffix", b"dns_suffix", "id", b"id", "name", b"name", "network", b"network", "parent", b"parent", "project", b"project", "resource_info", b"resource_info", "service", b"service", "timeouts", b"timeouts"]) -> None: ...

global___ServiceNetworkingPeeredDnsDomain = ServiceNetworkingPeeredDnsDomain



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_FrontDoor_NetworkExperimentProfiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_EXPERIMENT_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def network_experiment_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkExperimentProfiles]: ...
    def __init__(
        self,
        *,
        network_experiment_profiles: collections.abc.Iterable[global___NetworkExperimentProfiles] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_experiment_profiles", b"network_experiment_profiles"]) -> None: ...

global___Microsoft_Network_FrontDoor_NetworkExperimentProfiles = Microsoft_Network_FrontDoor_NetworkExperimentProfiles

@typing_extensions.final
class NetworkExperimentProfilesExperiments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    ENDPOINT_A_FIELD_NUMBER: builtins.int
    ENDPOINT_B_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    description: builtins.str
    enabled_state: builtins.str
    @property
    def endpoint_a(self) -> global___Endpoint: ...
    @property
    def endpoint_b(self) -> global___Endpoint: ...
    resource_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        enabled_state: builtins.str = ...,
        endpoint_a: global___Endpoint | None = ...,
        endpoint_b: global___Endpoint | None = ...,
        resource_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoint_a", b"endpoint_a", "endpoint_b", b"endpoint_b", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "enabled_state", b"enabled_state", "endpoint_a", b"endpoint_a", "endpoint_b", b"endpoint_b", "location", b"location", "name", b"name", "resource_info", b"resource_info", "resource_state", b"resource_state", "tags", b"tags"]) -> None: ...

global___NetworkExperimentProfilesExperiments = NetworkExperimentProfilesExperiments

@typing_extensions.final
class Endpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    endpoint: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        endpoint: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint", b"endpoint", "name", b"name"]) -> None: ...

global___Endpoint = Endpoint

@typing_extensions.final
class NetworkExperimentProfiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NETWORK_EXPERIMENT_PROFILES__EXPERIMENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    location: builtins.str
    name: builtins.str
    enabled_state: builtins.str
    resource_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def network_experiment_profiles__experiments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkExperimentProfilesExperiments]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        enabled_state: builtins.str = ...,
        resource_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_experiment_profiles__experiments: collections.abc.Iterable[global___NetworkExperimentProfilesExperiments] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled_state", b"enabled_state", "etag", b"etag", "location", b"location", "name", b"name", "network_experiment_profiles__experiments", b"network_experiment_profiles__experiments", "resource_info", b"resource_info", "resource_state", b"resource_state", "tags", b"tags"]) -> None: ...

global___NetworkExperimentProfiles = NetworkExperimentProfiles



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_IoTSecurity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Microsoft_IoTSecurity = Microsoft_IoTSecurity



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_certificate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_certificate.proto\x12\x1boak9.tython.gcp.certificate\x1a\x13shared/shared.proto\"c\n%CertificateManagerCertificateXManaged\x12\x1a\n\x12\x64ns_authorizations\x18\x01 \x03(\t\x12\x0f\n\x07\x64omains\x18\x02 \x03(\t\x12\r\n\x05state\x18\x03 \x01(\t\"]\n)CertificateManagerCertificateXSelfManaged\x12\x17\n\x0f\x63\x65rtificate_pem\x18\x01 \x01(\t\x12\x17\n\x0fprivate_key_pem\x18\x02 \x01(\t\"X\n&CertificateManagerCertificateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb8\x04\n\x1d\x43\x65rtificateManagerCertificate\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12V\n\x06labels\x18\x03 \x03(\x0b\x32\x46.oak9.tython.gcp.certificate.CertificateManagerCertificate.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12S\n\x07managed\x18\x07 \x01(\x0b\x32\x42.oak9.tython.gcp.certificate.CertificateManagerCertificateXManaged\x12\\\n\x0cself_managed\x18\x08 \x01(\x0b\x32\x46.oak9.tython.gcp.certificate.CertificateManagerCertificateXSelfManaged\x12U\n\x08timeouts\x18\t \x01(\x0b\x32\x43.oak9.tython.gcp.certificate.CertificateManagerCertificateXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n)CertificateManagerCertificateMapXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc3\x04\n CertificateManagerCertificateMap\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x64\n\x0cgclb_targets\x18\x03 \x03(\x0b\x32N.oak9.tython.gcp.certificate.CertificateManagerCertificateMap.GclbTargetsEntry\x12\n\n\x02id\x18\x04 \x01(\t\x12Y\n\x06labels\x18\x05 \x03(\x0b\x32I.oak9.tython.gcp.certificate.CertificateManagerCertificateMap.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12X\n\x08timeouts\x18\t \x01(\x0b\x32\x46.oak9.tython.gcp.certificate.CertificateManagerCertificateMapXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10GclbTargetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n.CertificateManagerCertificateMapEntryXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8d\x04\n%CertificateManagerCertificateMapEntry\x12\x14\n\x0c\x63\x65rtificates\x18\x01 \x03(\t\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08hostname\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12^\n\x06labels\x18\x06 \x03(\x0b\x32N.oak9.tython.gcp.certificate.CertificateManagerCertificateMapEntry.LabelsEntry\x12\x0b\n\x03map\x18\x07 \x01(\t\x12\x0f\n\x07matcher\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\x12\x13\n\x0bupdate_time\x18\x0c \x01(\t\x12]\n\x08timeouts\x18\r \x01(\x0b\x32K.oak9.tython.gcp.certificate.CertificateManagerCertificateMapEntryXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n+CertificateManagerDnsAuthorizationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc4\x04\n\"CertificateManagerDnsAuthorization\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12s\n\x13\x64ns_resource_record\x18\x02 \x03(\x0b\x32V.oak9.tython.gcp.certificate.CertificateManagerDnsAuthorization.DnsResourceRecordEntry\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12[\n\x06labels\x18\x05 \x03(\x0b\x32K.oak9.tython.gcp.certificate.CertificateManagerDnsAuthorization.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12Z\n\x08timeouts\x18\x08 \x01(\x0b\x32H.oak9.tython.gcp.certificate.CertificateManagerDnsAuthorizationXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x38\n\x16\x44nsResourceRecordEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_certificate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CERTIFICATEMANAGERCERTIFICATE_LABELSENTRY._options = None
  _CERTIFICATEMANAGERCERTIFICATE_LABELSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERCERTIFICATEMAP_GCLBTARGETSENTRY._options = None
  _CERTIFICATEMANAGERCERTIFICATEMAP_GCLBTARGETSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERCERTIFICATEMAP_LABELSENTRY._options = None
  _CERTIFICATEMANAGERCERTIFICATEMAP_LABELSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY_LABELSENTRY._options = None
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY_LABELSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERDNSAUTHORIZATION_DNSRESOURCERECORDENTRY._options = None
  _CERTIFICATEMANAGERDNSAUTHORIZATION_DNSRESOURCERECORDENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERDNSAUTHORIZATION_LABELSENTRY._options = None
  _CERTIFICATEMANAGERDNSAUTHORIZATION_LABELSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERCERTIFICATEXMANAGED._serialized_start=79
  _CERTIFICATEMANAGERCERTIFICATEXMANAGED._serialized_end=178
  _CERTIFICATEMANAGERCERTIFICATEXSELFMANAGED._serialized_start=180
  _CERTIFICATEMANAGERCERTIFICATEXSELFMANAGED._serialized_end=273
  _CERTIFICATEMANAGERCERTIFICATEXTIMEOUTS._serialized_start=275
  _CERTIFICATEMANAGERCERTIFICATEXTIMEOUTS._serialized_end=363
  _CERTIFICATEMANAGERCERTIFICATE._serialized_start=366
  _CERTIFICATEMANAGERCERTIFICATE._serialized_end=934
  _CERTIFICATEMANAGERCERTIFICATE_LABELSENTRY._serialized_start=889
  _CERTIFICATEMANAGERCERTIFICATE_LABELSENTRY._serialized_end=934
  _CERTIFICATEMANAGERCERTIFICATEMAPXTIMEOUTS._serialized_start=936
  _CERTIFICATEMANAGERCERTIFICATEMAPXTIMEOUTS._serialized_end=1027
  _CERTIFICATEMANAGERCERTIFICATEMAP._serialized_start=1030
  _CERTIFICATEMANAGERCERTIFICATEMAP._serialized_end=1609
  _CERTIFICATEMANAGERCERTIFICATEMAP_GCLBTARGETSENTRY._serialized_start=1512
  _CERTIFICATEMANAGERCERTIFICATEMAP_GCLBTARGETSENTRY._serialized_end=1562
  _CERTIFICATEMANAGERCERTIFICATEMAP_LABELSENTRY._serialized_start=889
  _CERTIFICATEMANAGERCERTIFICATEMAP_LABELSENTRY._serialized_end=934
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRYXTIMEOUTS._serialized_start=1611
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRYXTIMEOUTS._serialized_end=1707
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY._serialized_start=1710
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY._serialized_end=2235
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY_LABELSENTRY._serialized_start=889
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY_LABELSENTRY._serialized_end=934
  _CERTIFICATEMANAGERDNSAUTHORIZATIONXTIMEOUTS._serialized_start=2237
  _CERTIFICATEMANAGERDNSAUTHORIZATIONXTIMEOUTS._serialized_end=2330
  _CERTIFICATEMANAGERDNSAUTHORIZATION._serialized_start=2333
  _CERTIFICATEMANAGERDNSAUTHORIZATION._serialized_end=2913
  _CERTIFICATEMANAGERDNSAUTHORIZATION_DNSRESOURCERECORDENTRY._serialized_start=2810
  _CERTIFICATEMANAGERDNSAUTHORIZATION_DNSRESOURCERECORDENTRY._serialized_end=2866
  _CERTIFICATEMANAGERDNSAUTHORIZATION_LABELSENTRY._serialized_start=889
  _CERTIFICATEMANAGERDNSAUTHORIZATION_LABELSENTRY._serialized_end=934
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_detective.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_detective.proto\x12\x19oak9.tython.aws.detective\x1a\x13shared/shared.proto\"@\n\x05Graph\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x84\x01\n\tDetective\x12/\n\x05graph\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.detective.Graph\x12\x46\n\x11member_invitation\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.detective.MemberInvitation\"\xa0\x01\n\x10MemberInvitation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tgraph_arn\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12\x1c\n\x14member_email_address\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_detective_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GRAPH._serialized_start=75
  _GRAPH._serialized_end=139
  _DETECTIVE._serialized_start=142
  _DETECTIVE._serialized_end=274
  _MEMBERINVITATION._serialized_start=277
  _MEMBERINVITATION._serialized_end=437
# @@protoc_insertion_point(module_scope)
